EpsonEPOSCommand class

Constructors

EpsonEPOSCommand()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCut(EpsonEPOSCut data) → Map<String, dynamic>
addFeedLine(dynamic data) → Map<String, dynamic>
addLineSpace(dynamic data) → Map<String, dynamic>
addTextAlign(EpsonEPOSTextAlign data) → Map<String, dynamic>
append(dynamic data) → Map<String, dynamic>
appendBitmap(dynamic data, int width, int height, int posX, int posY) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rawData(Uint8List data) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited