EpsonPrinterModel class

Printer Model

Constructors

EpsonPrinterModel({String? type, String? ipAddress, String? bdAddress, String? macAddress, String? model, String? series, String? target})
EpsonPrinterModel.fromJson(String source)
factory
EpsonPrinterModel.fromMap(Map<String, dynamic> map)
factory

Properties

bdAddress ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
ipAddress ↔ String?
Addrs
getter/setter pair
macAddress ↔ String?
getter/setter pair
model ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series ↔ String?
getter/setter pair
target ↔ String?
getter/setter pair
type ↔ String?
Connectivity type: TCP | BT | USB
getter/setter pair

Methods

copyWith({String? type, String? ipAddress, String? bdAddress, String? macAddress, String? model, String? series, String? target}) → EpsonPrinterModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant EpsonPrinterModel other) → bool
The equality operator.
override