EpsonPrinterResponse class

Response

Constructors

EpsonPrinterResponse({required String type, required bool success, String? message, dynamic content})
EpsonPrinterResponse.fromJson(Map<String, dynamic> json)
factory
EpsonPrinterResponse.fromRawJson(String str)
factory

Properties

content ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool
getter/setter pair
type ↔ String
getter/setter pair

Methods

copyWith({required String type, required bool success, String? message, dynamic content}) → EpsonPrinterResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited